@@ -1,12 +1,12 @@
 """
-A wrapper for tqdm (https://github.com/tqdm/tqdm) that supports 
+A wrapper for tqdm (https://github.com/tqdm/tqdm) that supports
 multidimensional iterators. Iterates over the Cartesian product
 of the input iterators. Integers in the input are automagically
 conveted to range(i) for convenience.
 Examples:
 for x,y in tqdmnd(range(20),range(10)):
     sleep(0.1)
-    
+
 for x,y in tqdmnd(20,10):
     sleep(0.1)
 """
@@ -16,6 +16,7 @@ from tqdm import tqdm
 from itertools import product
 from functools import reduce
 from operator import mul
+from numpy import integer
 
 from collections.abc import Iterator
 
@@ -32,7 +33,7 @@ class nditer(Iterator):
         return self._it.__next__()
     def __len__(self):
         return self._l
-      
+
 def tqdmnd(*args,**kwargs):
-    r = [range(i) if isinstance(i,int) else i for i in args]
-    return tqdm(nditer(*r),**kwargs)
\ No newline at end of file
+    r = [range(i) if isinstance(i,(int,integer)) else i for i in args]
+    return tqdm(nditer(*r),**kwargs)
